################################################################################
## 	Licensed Materials - Property of IBM
##
##    TIVOCIT00
##
## 	(C) Copyright IBM Corp. 2009-2010 All Rights Reserved.
##
##	US Government Users Restricted Rights - Use, duplication,
## 	or disclosure restricted by GSA ADP Schedule Contract with
## 	IBM Corp.
##
##    Version: src/enabler/VMWare/linux/retrieve.sh, cit, cit_2.7fp1, 20110505v27fp1
##    Build date: 11/05/05 12:02:05
##
################################################################################

#!/bin/sh

#log file in verbose mode
OUTPUTFILE="./retr_out.txt"
REPORTFILE="./en_report.txt"

DOREPORT=0
DOFORCE=0
VERBOSE=0

while true; do
    if [ "$1" == "-r" ]; then
        DOREPORT=1
        shift
    elif [ "$1" == "-f" ]; then
        DOFORCE=1
        shift
    elif [ "$1" == "-vm" ]; then
        THE_VM=$2
        shift
        shift
    elif [ "$1" == "-v" ] || [ "$1" == "--verbose" ] || [ "$1" == "--debug" ]; then
        VERBOSE=1
        shift
    else
        break
    fi
done

if [ "$7" == "-v" ] || [ "$7" == "--verbose" ] || [ "$7" == "--debug" ]; then
    VERBOSE=1
fi

if [ $VERBOSE -eq 1 ]; then
    DOREPORT=1
fi

if [ "$CITENABLER_FORCE" == "y" ]; then
    DOFORCE=1
fi

#values from dispatcher
NODE_ID=$1
NODE_MAN=$2
NODE_PROD=$3
NODE_VER=$4
NODE_TYPE=$5
NODE_CAPACITY=$6
PROCESSOR=$7

# redirects output to a file
function verbose()
{
    if [ $VERBOSE -eq 1 ]; then
        echo "[`date \"+%D %H:%M:%S\"`] $1" >> $OUTPUTFILE
    fi
}

function report()
{
    if [ $DOREPORT -eq 1 ]; then
        echo "$1" >> $REPORTFILE
    fi
}


#attempts to set guest info and verifies if it was successfull
function setAndTest() {
	local VM=$1
    local KEY=$2
	#remove ""
	local VALUE=$3; #`echo $3 | sed 's/\"//g'`
	
	getGuestInfo "$VM" "$KEY"
	verbose "setAndTest: $VM $KEY $VALUE"
	verbose "value to set: ($VALUE); current value: ($GET_RETURN)"
	verbose "before while"
	
	LIMIT=10
	a=1
	
	while [[ "$VALUE" != "$GET_RETURN" && "$a" -le $LIMIT ]]
	do
		verbose "inside while; $a round"
		sleep 1
		setGuestInfo "$VM" $KEY "$VALUE"
		#sleep period increments after each failure
		sleep $a
		getGuestInfo "$VM" "$KEY"

		let "a+=1"
	done

	verbose "after while"
	
	if [ "$VALUE" != "$GET_RETURN" ]
	then
		verbose "WARNING: set failed"
	else
		verbose "OK: set sucessfull"
		let "SET_COUNT+=1"
	fi
	

}

#sets guest info
function setGuestInfo()
{
	local VM=$1
    local KEY=$2
	local VALUE=$3
	sleep 1
	CMD="/usr/bin/vmware-cmd  \"$VM\"  \"setguestinfo\" \"$KEY\" \"$VALUE\" 2>&1"
	verbose "setGuestInfo cmd: $CMD"
	local OUTPUT="`eval \"$CMD\"`"
	verbose "cmd output: $OUTPUT"
}

#reads guest info to global $GET_RETURN variable
function getGuestInfo()
{
	local VM=$1
    local KEY=$2
	sleep 1
	CMD="/usr/bin/vmware-cmd  \"$VM\"  \"getguestinfo\" \"$KEY\" 2>&1 | sed 's/.*= //'"
	verbose "getGuestInfo cmd: $CMD"
	local OUTPUT="`eval \"$CMD\"`"
	verbose "cmd output: ($OUTPUT)"
	GET_RETURN="$OUTPUT"
}

function getGuestState()
{
	local VM=$1
	CMD="/usr/bin/vmware-cmd  \"$VM\"  getstate 2>/dev/null"
	local OUTPUT="`eval \"$CMD\"`"
	verbose "getGuestState($VM): '$OUTPUT'"
    VM_STATE=off
    for token in $OUTPUT
    do
        if [ "$token" == "on" ]; then
            VM_STATE=on
        fi
    done
    verbose "VM_STATE($VM)=$VM_STATE"
}


report ""
report "----------------------------------------------------------"
report "REPORT STARTED ON `date`"


verbose ""
verbose "----------------------------------------------------------"
verbose "Started on `date`"
verbose "----------------------------------------------------------"
verbose "Shell retrieve start"
verbose "passed arguments:"
verbose "NODE_ID = $NODE_ID"
verbose "NODE_MAN = $NODE_MAN"
verbose "NODE_PROD = $NODE_PROD"
verbose "NODE_VER = $NODE_VER"
verbose "NODE_TYPE = $NODE_TYPE"
verbose "NODE_CAPACITY = $NODE_CAPACITY"
verbose "PHYSICAL_PROCESSOR = $PHYSICAL_PROCESSOR"
if [ -n "$PHYSICAL_PROCESSOR" ]; then
    PROCESSOR="$PHYSICAL_PROCESSOR"
fi
verbose "PROCESSOR = $PROCESSOR"

verbose "entering main loop..."

vmware-cmd -l|while read vm;
do
	if [ -z "$vm" ]; then
	continue
	fi
    
    if [ -n "$THE_VM" ]; then
        verbose "Checking if $vm is $THE_VM..."
        if [ "$vm" != "$THE_VM" ]; then
            verbose "Nope, skipping."
            continue;
        fi
    fi
    
    report "----------------------------------------------------------"
    report "$vm"
    
    if [ $DOFORCE -ne 1 ]; then
        getGuestState "$vm"
        if [ "$VM_STATE" == "off" ]; then
            verbose "$vm appears not to be running. Skipping."
            report "    VM appears not to be running. Skipping."
            report "    In order to force enabler on the vm run command:"
            report "        ./retrieve.sh -v -f -vm \"$vm\" \"$NODE_ID\" \"$NODE_MAN\" \"$NODE_PROD\" \"$NODE_VER\" \"$NODE_TYPE\" \"$NODE_CAPACITY\" \"$PROCESSOR\""
            continue
        fi
    fi
    
    verbose "Start transferring data to $vm"
    
	verbose "\$vm = $vm"
	UUID_BIOS="`vmware-cmd \"$vm\" \"getconfig\" \"uuid.bios\" | sed 's/.*= //'`"
	verbose "\$UUID_BIOS = $UUID_BIOS"
	DISPLAY_NAME="`vmware-cmd \"$vm\" \"getconfig\" \"displayName\" | sed 's/.*= //'`"
	verbose "\$DISPLAY_NAME = $DISPLAY_NAME"
	VM_ID="${DISPLAY_NAME}_${UUID_BIOS}"
	verbose "\$VM_ID = $VM_ID"
	#CPU_MAX="`vmware-cmd \"$vm\" \"getresource\" \"cpu.max\" | sed 's/.*= //'`"
	# VM_CAPACITY = $CPU_MAX/100
	#VM_CAPACITY is for backward compatibility only
	VM_CAPACITY="0"
	verbose "\$VM_CAPACITY = $VM_CAPACITY"

    SET_COUNT=0
    TOTAL_COUNT=9
    
	setAndTest "$vm" CIT_NODE_ID "$NODE_ID"
	setAndTest "$vm" CIT_NODE_MAN "$NODE_MAN"
	setAndTest "$vm" CIT_NODE_PROD "$NODE_PROD"
	setAndTest "$vm" CIT_NODE_VER "$NODE_VER"
	setAndTest "$vm" CIT_NODE_TYPE "$NODE_TYPE"
	setAndTest "$vm" CIT_NODE_CAPACITY "$NODE_CAPACITY"
	setAndTest "$vm" CIT_VM_ID "$VM_ID"
	setAndTest "$vm" CIT_VM_CAPACITY "$VM_CAPACITY"
	setAndTest "$vm" CIT_PHYSICAL_PROCESSOR "$PROCESSOR"
    
    verbose "$vm set $SET_COUNT out of $TOTAL_COUNT"
    report "    Transfer succeeded for $SET_COUNT/$TOTAL_COUNT items"
    if [ "$SET_COUNT" -eq "$TOTAL_COUNT" ]; then
        report "    SUCCESS! All data transferred to the VM."
    else
        verbose "ERROR! Failed to transfer all data to $vm"
        report "    ERROR! Failed to transfer all data to the VM."
        report "    In order to retry enabler for this vm only run command:"
        report "        ./retrieve.sh -v -f -vm \"$vm\" \"$NODE_ID\" \"$NODE_MAN\" \"$NODE_PROD\" \"$NODE_VER\" \"$NODE_TYPE\" \"$NODE_CAPACITY\" \"$PROCESSOR\""
    fi
    
done

report "----------------------------------------------------------"
report "REPORT FINISHED ON `date`"
report "----------------------------------------------------------"

verbose "after main loop"
verbose "----------------------------------------------------------"
verbose "Finished on `date`"
verbose "----------------------------------------------------------"

